---
title: "Welcome to Doks"
description: ""
lead: "Congrats on setting up a new Doks project!"
draft: false
seo:
  title: "Welcome to Doks" # custom title (optional)
  description: "" # custom description (recommended)
  canonical: "" # custom canonical URL (optional)
  noindex: false # false (default) or true
---
